@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import json
-import prefect
 import os
 import psycopg2
 
@@ -124,9 +123,7 @@ def task_setup_secrets(secrets_path: str = "secrets.json", **kwargs):
             cursor.execute("select meta.get_secret(%s)", [secret_name])
             (content,) = cursor.fetchone()
             if content is None:
-                raise Exception(
-                    "Secret does not exist or is not accessible", secret_name
-                )
+                print("Secret does not exist or is not accessible", secret_name)
             else:
                 Secret.parse(definition).store(content)
 
